==> mule-artifact-ast-serialization-1.4.8-20250725.212218-16-test-sources.jar: org/mule/runtime/ast/test/internal/serialization/json/JsonArtifactAstDeserializerTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.test.internal.serialization.json;

import static org.mule.runtime.ast.AllureConstants.ArtifactAstSerialization.AST_JSON_DESERIALIZER;
import static org.mule.runtime.ast.AllureConstants.ArtifactAstSerialization.AST_SERIALIZATION;

import static org.hamcrest.MatcherAssert.assertThat;
import static org.hamcrest.Matchers.is;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.RETURNS_DEEP_STUBS;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import org.mule.runtime.ast.api.ArtifactAst;
import org.mule.runtime.ast.api.serialization.ExtensionModelResolver;
import org.mule.runtime.ast.internal.serialization.dto.ArtifactAstDTO;
import org.mule.runtime.ast.internal.serialization.json.JsonArtifactAstDeserializer;
import org.mule.runtime.ast.internal.serialization.json.JsonArtifactAstSerializerFormat;
import org.mule.runtime.ast.internal.serialization.resolver.GenerationInformationResolver;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

import org.junit.Before;
import org.junit.Test;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameter;
import org.junit.runners.Parameterized.Parameters;
import org.mockito.Mockito;

@Feature(AST_SERIALIZATION)
@Story(AST_JSON_DESERIALIZER)
@RunWith(Parameterized.class)
public class JsonArtifactAstDeserializerTestCase {

  @Parameters(name = "version: {0}")
  public static Iterable<String> data() {
    return new JsonArtifactAstSerializerFormat().getAvailableVersions();
  }

  private JsonArtifactAstDeserializer jsonArtifactAstDeserializer;
  private Gson gson;
  private ArtifactAstDTO artifactAstDTO;

  @Parameter
  public String version;

  @Before
  public void setUp() throws Exception {
    GsonBuilder gsonBuilder = mock(GsonBuilder.class);
    gson = mock(Gson.class);
    when(gson.newBuilder()).thenReturn(gsonBuilder);
    when(gsonBuilder.registerTypeAdapterFactory(any())).thenReturn(gsonBuilder);
    when(gsonBuilder.create()).thenReturn(gson);
    artifactAstDTO = mock(ArtifactAstDTO.class);
    when(gson.fromJson(any(Reader.class), eq(ArtifactAstDTO.class))).thenReturn(artifactAstDTO);
    jsonArtifactAstDeserializer = new JsonArtifactAstDeserializer(gsonBuilder, version, true);
  }

  @Test
  public void testDeserializeCallGsonFromJsonForArtifactAstDTOClass_WhenDeserializingAnInputStream() throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);

    // When
    jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver);

    // Then
    verify(gson, times(1)).fromJson(any(Reader.class), eq(ArtifactAstDTO.class));
  }

  @Test
  public void testDeserializeCallGsonFromJsonResultsEnrich_WhenDeserializingAnInputStream() throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);

    // When
    jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver);

    // Then
    verify(artifactAstDTO, times(1)).enrich(any(ExtensionModelResolver.class), any(GenerationInformationResolver.class));
  }

  @Test
  @Issue("MULE-19834")
  public void testDeserializeCallsResultingArtifactSetParentWithInputParent_WhenDeserializingAnInputStreamWithParent()
      throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);
    ArtifactAst parent = mock(ArtifactAst.class);

    // When
    jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver, parent);

    // Then
    verify(artifactAstDTO, times(1)).setParent(parent);
  }

  @Test
  public void testDeserializeReturnsEnrichedArtifactAst_WhenDeserializingAnInputStream() throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);

    // When
    ArtifactAst artifactAst = jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver);

    // Then
    assertThat(artifactAst, is(artifactAstDTO));
  }

}

==> mule-artifact-ast-serialization-1.7.0-20251202.122845-59-test-sources.jar: org/mule/runtime/ast/test/internal/serialization/json/JsonArtifactAstDeserializerTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.ast.test.internal.serialization.json;

import static org.mule.runtime.ast.AllureConstants.ArtifactAstSerialization.AST_JSON_DESERIALIZER;
import static org.mule.runtime.ast.AllureConstants.ArtifactAstSerialization.AST_SERIALIZATION;

import static org.hamcrest.MatcherAssert.assertThat;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

import static org.hamcrest.Matchers.is;
import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.eq;

import org.mule.runtime.ast.api.ArtifactAst;
import org.mule.runtime.ast.api.serialization.ExtensionModelResolver;
import org.mule.runtime.ast.internal.model.ParameterModelUtils;
import org.mule.runtime.ast.internal.serialization.dto.ArtifactAstDTO;
import org.mule.runtime.ast.internal.serialization.json.JsonArtifactAstDeserializer;
import org.mule.runtime.ast.internal.serialization.json.JsonArtifactAstSerializerFormat;
import org.mule.runtime.ast.internal.serialization.resolver.GenerationInformationResolver;

import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameter;
import org.junit.runners.Parameterized.Parameters;

import io.qameta.allure.Feature;
import io.qameta.allure.Issue;
import io.qameta.allure.Story;

@Feature(AST_SERIALIZATION)
@Story(AST_JSON_DESERIALIZER)
@RunWith(Parameterized.class)
public class JsonArtifactAstDeserializerTestCase {

  @Parameters(name = "version: {0}")
  public static Iterable<String> data() {
    return new JsonArtifactAstSerializerFormat().getAvailableVersions();
  }

  private JsonArtifactAstDeserializer jsonArtifactAstDeserializer;
  private Gson gson;
  private ArtifactAstDTO artifactAstDTO;

  @Parameter
  public String version;

  @Before
  public void setUp() throws Exception {
    GsonBuilder gsonBuilder = mock(GsonBuilder.class);
    gson = mock(Gson.class);
    when(gson.newBuilder()).thenReturn(gsonBuilder);
    when(gsonBuilder.registerTypeAdapterFactory(any())).thenReturn(gsonBuilder);
    when(gsonBuilder.create()).thenReturn(gson);
    artifactAstDTO = mock(ArtifactAstDTO.class);
    when(gson.fromJson(any(Reader.class), eq(ArtifactAstDTO.class))).thenReturn(artifactAstDTO);
    jsonArtifactAstDeserializer = new JsonArtifactAstDeserializer(gsonBuilder, version, true);
  }

  @Test
  public void testDeserializeCallGsonFromJsonForArtifactAstDTOClass_WhenDeserializingAnInputStream() throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);

    // When
    jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver);

    // Then
    verify(gson, times(1)).fromJson(any(Reader.class), eq(ArtifactAstDTO.class));
  }

  @Test
  public void testDeserializeCallGsonFromJsonResultsEnrich_WhenDeserializingAnInputStream() throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);

    // When
    jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver);

    // Then
    verify(artifactAstDTO, times(1)).enrich(any(ExtensionModelResolver.class),
                                            any(GenerationInformationResolver.class),
                                            any(ParameterModelUtils.class));
  }

  @Test
  @Issue("MULE-19834")
  public void testDeserializeCallsResultingArtifactSetParentWithInputParent_WhenDeserializingAnInputStreamWithParent()
      throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);
    ArtifactAst parent = mock(ArtifactAst.class);

    // When
    jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver, parent);

    // Then
    verify(artifactAstDTO, times(1)).setParent(parent);
  }

  @Test
  public void testDeserializeReturnsEnrichedArtifactAst_WhenDeserializingAnInputStream() throws IOException {
    // Given
    InputStream artifactAstInputStream = mock(InputStream.class);
    ExtensionModelResolver extensionModelResolver = mock(ExtensionModelResolver.class);

    // When
    ArtifactAst artifactAst = jsonArtifactAstDeserializer.deserialize(artifactAstInputStream, extensionModelResolver);

    // Then
    assertThat(artifactAst, is(artifactAstDTO));
  }

}
